"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SchemaProperty = void 0;
var SchemaPropertyType_1 = require("./SchemaPropertyType");
var SchemaProperty = /** @class */ (function () {
    function SchemaProperty(name, sourceObj) {
        var _this = this;
        this._types = [];
        this._required = false;
        this._shorthands = [];
        this._examples = [];
        this._original = sourceObj;
        this._name = name;
        if (sourceObj.description) {
            this._description = sourceObj.description;
        }
        if (sourceObj.required) {
            this._required = true;
        }
        if (sourceObj.shorthands) {
            sourceObj.shorthands.forEach(function (shorthand) {
                _this._shorthands.push(new SchemaProperty(name, shorthand));
            });
        }
        if (sourceObj.default) {
            this._default = sourceObj.default;
        }
        if (sourceObj.examples) {
            this._examples = sourceObj.examples;
        }
        if (sourceObj.override) {
            this._override = true;
        }
    }
    Object.defineProperty(SchemaProperty.prototype, "name", {
        get: function () {
            return this._name;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SchemaProperty.prototype, "original", {
        get: function () {
            return this._original;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SchemaProperty.prototype, "types", {
        get: function () {
            return this._types;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SchemaProperty.prototype, "description", {
        get: function () {
            return this._description;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SchemaProperty.prototype, "required", {
        get: function () {
            return this._required;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SchemaProperty.prototype, "shorthands", {
        get: function () {
            return this._shorthands;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SchemaProperty.prototype, "default", {
        get: function () {
            return this._default;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SchemaProperty.prototype, "examples", {
        get: function () {
            return this._examples;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SchemaProperty.prototype, "override", {
        get: function () {
            return this._override;
        },
        enumerable: false,
        configurable: true
    });
    SchemaProperty.prototype.resolve = function (types) {
        var _this = this;
        // Resolve type
        if (!this.original.type) {
            throw new Error("type property on property wasn't provided.");
        }
        this.original.type.split("|").forEach(function (type) {
            _this._types.push(new SchemaPropertyType_1.SchemaPropertyType(type, types));
        });
        // Resolve shorthands
        this._shorthands.forEach(function (shorthand) {
            shorthand.resolve(types);
        });
    };
    SchemaProperty.prototype.getAllTypes = function () {
        var answer = [];
        this.types.forEach(function (type) {
            answer.push(type);
        });
        this.shorthands.forEach(function (shorthand) {
            shorthand.types.forEach(function (type) {
                answer.push(type);
            });
        });
        return answer;
    };
    return SchemaProperty;
}());
exports.SchemaProperty = SchemaProperty;
//# sourceMappingURL=SchemaProperty.js.map